@@ -28,13 +28,13 @@ class DataFrame(object):
     __slots__ = ["_data", "_index", "_index_name", "_columns", "_sort", "_dropin"]
 
     def __init__(
-        self,
-        data: dict[Any, list | Any] | None = None,
-        columns: list | None = None,
-        index: list | None = None,
-        index_name: str | tuple | None = "index",
-        sort: bool | None = None,
-        dropin: Callable = None,
+            self,
+            data: dict[Any, list | Any] | None = None,
+            columns: list | None = None,
+            index: list | None = None,
+            index_name: str | tuple | None = "index",
+            sort: bool | None = None,
+            dropin: Callable = None,
     ):
         """
         :param data: (optional) dictionary of lists. The keys of the dictionary will be used for the column names and\
@@ -81,10 +81,11 @@ class DataFrame(object):
             # set data from dict values. If dict value is not a list, wrap it to make a single element list
             self._data = (
                 dropin(
-                    [dropin(x) if ((type(x) == dropin) or (type(x) == list)) else dropin([x]) for x in data.values()]
+                    [dropin(x) if ((isinstance(x, dropin)) or (isinstance(x, list))) else dropin([x]) for x in
+                     data.values()]
                 )
                 if dropin
-                else [x if type(x) == list else [x] for x in data.values()]
+                else [x if isinstance(x, list) else [x] for x in data.values()]
             )
             # setup columns from directory keys
             self.columns = data.keys()
@@ -123,8 +124,8 @@ class DataFrame(object):
     def __str__(self) -> str:
         return self._make_table()
 
-    def _check_list(self, x: list) -> bool:
-        return type(x) == (self._dropin if self._dropin else list)
+    def _check_list(self, x: Any) -> bool:
+        return isinstance(x, self._dropin) if self._dropin else isinstance(x, list)
 
     def _make_table(self, index: bool = True, **kwargs) -> str:
         kwargs["headers"] = "keys" if "headers" not in kwargs.keys() else kwargs["headers"]
@@ -148,7 +149,7 @@ class DataFrame(object):
         :param columns_list: list of column names. Must include all column names
         :return: nothing
         """
-        if not (all([x in columns_list for x in self._columns]) and all([x in self._columns for x in columns_list])):
+        if set(columns_list) != set(self._columns):
             raise ValueError(
                 "columns_list must be all in current columns, and all current columns must be in columns_list"
             )
@@ -256,11 +257,11 @@ class DataFrame(object):
             raise ValueError("only valid values for result parameter are: boolean or value.")
 
     def get(
-        self,
-        indexes: Any | list[Any | bool] = None,
-        columns: Any | list = None,
-        as_list: bool = False,
-        as_dict: bool = False,
+            self,
+            indexes: Any | list[Any | bool] = None,
+            columns: Any | list = None,
+            as_list: bool = False,
+            as_dict: bool = False,
     ) -> Self | list | dict | Any:
         """
         Given indexes and columns will return a sub-set of the DataFrame. This method will direct to the below methods
@@ -314,7 +315,7 @@ class DataFrame(object):
         :return: DataFrame is as_list if False, a list if as_list is True
         """
         c = self._columns.index(column)
-        if all([isinstance(i, bool) for i in indexes]):  # boolean list
+        if indexes and isinstance(indexes[0], bool) and all(isinstance(i, bool) for i in indexes):  # boolean list
             if len(indexes) != len(self._index):
                 raise ValueError("boolean index list must be same size of existing index")
             if all(indexes):  # the entire column
@@ -338,13 +339,13 @@ class DataFrame(object):
         )
 
     def get_columns(
-        self,
-        index: Any,
-        columns: list[Any] = None,
-        as_dict: bool = False,
-        as_namedtuple: bool = False,
-        name: str = "raccoon",
-        include_index: bool = True,
+            self,
+            index: Any,
+            columns: list[Any] = None,
+            as_dict: bool = False,
+            as_namedtuple: bool = False,
+            name: str = "raccoon",
+            include_index: bool = True,
     ) -> Self | dict | namedtuple:
         """
         For a single index and list of column names return a DataFrame of the values in that index as either a dict
@@ -392,7 +393,7 @@ class DataFrame(object):
         """
         bool_indexes = []
         locations = []
-        if all([isinstance(i, bool) for i in indexes]):  # boolean list
+        if indexes and isinstance(indexes[0], bool) and all(isinstance(i, bool) for i in indexes):  # boolean list
             is_bool_indexes = True
             if len(indexes) != len(self._index):
                 raise ValueError("boolean index list must be same size of existing index")
@@ -406,7 +407,7 @@ class DataFrame(object):
                 else [self._index.index(x) for x in indexes]
             )
 
-        if all([isinstance(i, bool) for i in columns]):  # boolean list
+        if columns and isinstance(columns[0], bool) and all(isinstance(i, bool) for i in columns):  # boolean list
             if len(columns) != len(self._columns):
                 raise ValueError("boolean column list must be same size of existing columns")
             columns = list(compress(self._columns, columns))
@@ -424,13 +425,13 @@ class DataFrame(object):
         return DataFrame(data=data_dict, index=indexes, columns=columns, index_name=self._index_name, sort=self._sort)
 
     def get_location(
-        self,
-        location: int,
-        columns: Any | list | None = None,
-        as_dict: bool = False,
-        as_namedtuple: bool = False,
-        name: str = "raccoon",
-        index: bool = True,
+            self,
+            location: int,
+            columns: Any | list | None = None,
+            as_dict: bool = False,
+            as_namedtuple: bool = False,
+            name: str = "raccoon",
+            index: bool = True,
     ) -> Self | dict | namedtuple | Any:
         """
         For an index location and either (1) list of columns return a DataFrame or dictionary of the values or
@@ -452,14 +453,14 @@ class DataFrame(object):
         elif not isinstance(columns, list):  # single value for columns
             c = self._columns.index(columns)
             return self._data[c][location]
-        elif all([isinstance(i, bool) for i in columns]):
+        elif columns and isinstance(columns[0], bool) and all(isinstance(i, bool) for i in columns):
             if len(columns) != len(self._columns):
                 raise ValueError("boolean column list must be same size of existing columns")
             columns = list(compress(self._columns, columns))
+        col_to_idx = {col: i for i, col in enumerate(self._columns)}
         data = dict()
         for column in columns:
-            c = self._columns.index(column)
-            data[column] = self._data[c][location]
+            data[column] = self._data[col_to_idx[column]][location]
         index_value = self._index[location]
         if as_dict:
             if index:
@@ -489,7 +490,7 @@ class DataFrame(object):
         return self.get(indexes, columns, **kwargs)
 
     def get_slice(
-        self, start_index: Any = None, stop_index: Any = None, columns: list | None = None, as_dict: bool = False
+            self, start_index: Any = None, stop_index: Any = None, columns: list | None = None, as_dict: bool = False
     ) -> Self | tuple:
         """
         For sorted DataFrames will return either a DataFrame or dict of all the rows where the index is greater than
@@ -508,7 +509,7 @@ class DataFrame(object):
 
         if columns is None:
             columns = self._columns
-        elif all([isinstance(i, bool) for i in columns]):
+        elif columns and isinstance(columns[0], bool) and all(isinstance(i, bool) for i in columns):
             if len(columns) != len(self._columns):
                 raise ValueError("boolean column list must be same size of existing columns")
             columns = list(compress(self._columns, columns))
@@ -517,10 +518,10 @@ class DataFrame(object):
         stop_location = bisect_right(self._index, stop_index) if stop_index is not None else None
 
         index = self._index[start_location:stop_location]
+        col_to_idx = {col: i for i, col in enumerate(self._columns)}
         data = dict()
         for column in columns:
-            c = self._columns.index(column)
-            data[column] = self._data[c][start_location:stop_location]
+            data[column] = self._data[col_to_idx[column]][start_location:stop_location]
 
         if as_dict:
             return index, data
@@ -558,7 +559,8 @@ class DataFrame(object):
         :param indexes: list of indexes
         :return: nothing
         """
-        new_indexes = [x for x in indexes if x not in self._index]
+        existing = set(self._index)
+        new_indexes = [x for x in indexes if x not in existing]
         for x in new_indexes:
             self._insert_row(bisect_left(self._index, x), x)
 
@@ -581,7 +583,8 @@ class DataFrame(object):
         :param indexes: list of indexes
         :return: nothing
         """
-        new_indexes = [x for x in indexes if x not in self._index]
+        existing = set(self._index)
+        new_indexes = [x for x in indexes if x not in existing]
         for x in new_indexes:
             self._add_row(x)
 
@@ -599,7 +602,7 @@ class DataFrame(object):
             self._data.append([None] * len(self._index))
 
     def set(
-        self, indexes: Any | list | list[bool] = None, columns: Any | None = None, values: Any | list = None
+            self, indexes: Any | list | list[bool] = None, columns: Any | None = None, values: Any | list = None
     ) -> None:
         """
         Given indexes and columns will set a sub-set of the DataFrame to the values provided. This method will direct
@@ -626,7 +629,7 @@ class DataFrame(object):
         else:
             raise ValueError("either or both of indexes or columns must be provided")
 
-    def set_cell(self, index, column, value):
+    def set_cell(self, index: Any, column: Any, value: Any) -> None:
         """
         Sets the value of a single cell. If the index and/or column is not in the current index/columns then a new
         index and/or column will be created.
@@ -653,7 +656,7 @@ class DataFrame(object):
             self._add_column(column)
         self._data[c][i] = value
 
-    def set_row(self, index, values):
+    def set_row(self, index: Any, values: dict[str, Any] | Any) -> None:
         """
         Sets the values of the columns in a single row.
 
@@ -697,7 +700,7 @@ class DataFrame(object):
             c = len(self._columns)
             self._add_column(column)
         if index:  # index was provided
-            if all([isinstance(i, bool) for i in index]):  # boolean list
+            if index and isinstance(index[0], bool) and all(isinstance(i, bool) for i in index):  # boolean list
                 if not self._check_list(values):  # single value provided, not a list, so turn values into list
                     values = [values for x in index if x]
                 if len(index) != len(self._index):
@@ -714,9 +717,12 @@ class DataFrame(object):
                     raise ValueError("length of values and index must be the same.")
                 # insert or append indexes as needed
                 if self._sort:
-                    exists_tuples = list(zip(*[sorted_exists(self._index, x) for x in index]))
-                    exists = exists_tuples[0]
-                    indexes = exists_tuples[1]
+                    exists = []
+                    indexes = []
+                    for x in index:
+                        e, i = sorted_exists(self._index, x)
+                        exists.append(e)
+                        indexes.append(i)
                     if not all(exists):
                         self._insert_missing_rows(index)
                         indexes = [sorted_index(self._index, x) for x in index]
@@ -769,7 +775,7 @@ class DataFrame(object):
         indexes = [self._index[x] for x in locations]
         self.set(indexes, column, values)
 
-    def append_row(self, index, values, new_cols=True):
+    def append_row(self, index: Any, values: dict[str, Any], new_cols: bool = True) -> None:
         """
         Appends a row of values to the end of the data. If there are new columns in the values and new_cols is True
         they will be added. Be very careful with this function as for sort DataFrames it will not enforce sort order.
@@ -796,7 +802,7 @@ class DataFrame(object):
         for c, col in enumerate(self._columns):
             self._data[c].append(values.get(col, None))
 
-    def append_rows(self, indexes, values, new_cols=True):
+    def append_rows(self, indexes: list[Any], values: dict[str, list[Any]], new_cols: bool = True) -> None:
         """
         Appends rows of values to the end of the data. If there are new columns in the values and new_cols is True
         they will be added. Be very careful with this function as for sort DataFrames it will not enforce sort order.
@@ -843,13 +849,8 @@ class DataFrame(object):
         if end_index < start_index:
             raise IndexError("end of slice is before start of slice")
 
-        pre_list = [False] * start_index
-        mid_list = [True] * (end_index - start_index + 1)
-        post_list = [False] * (len(self._index) - 1 - end_index)
-
-        pre_list.extend(mid_list)
-        pre_list.extend(post_list)
-        return pre_list
+        index_len = len(self._index)
+        return [False] * start_index + [True] * (end_index - start_index + 1) + [False] * (index_len - 1 - end_index)
 
     def __getitem__(self, index):
         """
@@ -952,7 +953,8 @@ class DataFrame(object):
         for key in self.__slots__:
             if key not in ["_data", "_index"]:
                 value = self.__getattribute__(key)
-                meta_data[key.lstrip("_")] = value if not type(value) == self._dropin else list(value)
+                meta_data[key.lstrip("_")] = value if not (self._dropin and isinstance(value, self._dropin)) else list(
+                    value)
         input_dict["meta_data"] = meta_data
         return json.dumps(input_dict, default=repr)
 
@@ -998,7 +1000,7 @@ class DataFrame(object):
         :return: nothing
         """
         indexes = [indexes] if not self._check_list(indexes) else indexes
-        if all([isinstance(i, bool) for i in indexes]):  # boolean list
+        if indexes and isinstance(indexes[0], bool) and all(isinstance(i, bool) for i in indexes):  # boolean list
             if len(indexes) != len(self._index):
                 raise ValueError("boolean indexes list must be same size of existing indexes")
             indexes = [i for i, x in enumerate(indexes) if x]
@@ -1009,11 +1011,9 @@ class DataFrame(object):
                 else [self._index.index(x) for x in indexes]
             )
         indexes = sorted(indexes, reverse=True)  # need to sort and reverse list so deleting works
-        for c, _ in enumerate(self._columns):
-            for i in indexes:
-                del self._data[c][i]
-        # now remove from index
         for i in indexes:
+            for c in range(len(self._columns)):
+                del self._data[c][i]
             del self._index[i]
 
     def delete_all_rows(self):
@@ -1154,10 +1154,10 @@ class DataFrame(object):
         right_list = self.get_rows(indexes, right_column, as_list=True)
         return left_list, right_list
 
-    def add(self, left_column, right_column, indexes=None):
+    def add(self, left_column: Any, right_column: Any, indexes: list | list[bool] | None = None) -> list:
         """
-        Math helper method that adds element-wise two columns. If indexes are not None then will only perform the math
-        on that sub-set of the columns.
+        Math helper method that adds element-wise two columns. If indexes are not None then will only perform the
+        math on that sub-set of the columns.
 
         :param left_column: first column name
         :param right_column: second column name
@@ -1166,9 +1166,9 @@ class DataFrame(object):
         :return: list
         """
         left_list, right_list = self._get_lists(left_column, right_column, indexes)
-        return [l + r for l, r in zip(left_list, right_list)]
+        return [left_val + r for left_val, r in zip(left_list, right_list)]
 
-    def subtract(self, left_column, right_column, indexes=None):
+    def subtract(self, left_column: Any, right_column: Any, indexes: list | list[bool] | None = None) -> list:
         """
         Math helper method that subtracts element-wise two columns. If indexes are not None then will only perform the
         math on that sub-set of the columns.
@@ -1180,9 +1180,9 @@ class DataFrame(object):
         :return: list
         """
         left_list, right_list = self._get_lists(left_column, right_column, indexes)
-        return [l - r for l, r in zip(left_list, right_list)]
+        return [left_val - r for left_val, r in zip(left_list, right_list)]
 
-    def multiply(self, left_column, right_column, indexes=None):
+    def multiply(self, left_column: Any, right_column: Any, indexes: list | list[bool] | None = None) -> list:
         """
         Math helper method that multiplies element-wise two columns. If indexes are not None then will only perform the
         math on that sub-set of the columns.
@@ -1194,9 +1194,9 @@ class DataFrame(object):
         :return: list
         """
         left_list, right_list = self._get_lists(left_column, right_column, indexes)
-        return [l * r for l, r in zip(left_list, right_list)]
+        return [left_val * r for left_val, r in zip(left_list, right_list)]
 
-    def divide(self, left_column, right_column, indexes=None):
+    def divide(self, left_column: Any, right_column: Any, indexes: list | list[bool] | None = None) -> list:
         """
         Math helper method that divides element-wise two columns. If indexes are not None then will only perform the
         math on that sub-set of the columns.
@@ -1208,7 +1208,7 @@ class DataFrame(object):
         :return: list
         """
         left_list, right_list = self._get_lists(left_column, right_column, indexes)
-        return [l / r for l, r in zip(left_list, right_list)]
+        return [left_val / r for left_val, r in zip(left_list, right_list)]
 
     def isin(self, column: Any, compare_list: list) -> list[bool]:
         """
@@ -1218,7 +1218,8 @@ class DataFrame(object):
         :param compare_list: list of items to compare to
         :return: list of booleans
         """
-        return [x in compare_list for x in self._data[self._columns.index(column)]]
+        compare_set = set(compare_list)
+        return [x in compare_set for x in self._data[self._columns.index(column)]]
 
     def iterrows(self, index: bool = True) -> Iterator[dict]:
         """
